==> home-library-jcr-1.4.1-20140911.132141-77-sources.jar: org/gcube/common/homelibrary/jcr/workspace/JCRProperties.java <==
package org.gcube.common.homelibrary.jcr.workspace;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import javax.jcr.Node;
import javax.jcr.PathNotFoundException;
import javax.jcr.Property;
import javax.jcr.PropertyIterator;
import javax.jcr.RepositoryException;
import javax.jcr.Session;
import org.apache.commons.lang.Validate;
import org.apache.jackrabbit.util.Text;
import org.gcube.common.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.common.homelibrary.home.workspace.Properties;
import org.gcube.common.homelibrary.jcr.repository.JCRRepository;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class JCRProperties implements Properties {

	private static Logger logger = LoggerFactory.getLogger(JCRProperties.class);
	private static final String PROPERTIES = "hl:metadata";
	private String identifier;

	private Map<String,String> map;


	public JCRProperties(Node itemNode) throws RepositoryException, InternalErrorException {

//		System.out.println("get properties");
		this.identifier = itemNode.getIdentifier();
		try {
			this.map = getProp(itemNode);
		} catch (InternalErrorException e) {
			throw new InternalErrorException(e);
		}
	}
 
	 
	@Override
	public String getId() throws InternalErrorException {
//		System.out.println("get id");
		Session session = JCRRepository.getSession();
		try {
			Node node = session.getNodeByIdentifier(identifier);
			return node.getNode(PROPERTIES).getIdentifier();
		} catch (RepositoryException e) {
			throw new InternalErrorException(e);
		} finally {
			session.logout();
		}	
	}

	@Override
	public String getPropertyValue(String propertyName) throws InternalErrorException {
		Session session = JCRRepository.getSession();
		try {
			Node itemNode = session.getNodeByIdentifier(identifier);
			return itemNode.getNode(PROPERTIES).getProperty(propertyName).getString();
		} catch (PathNotFoundException e) {
			return null;
		} catch (RepositoryException e) {
			throw new InternalErrorException(e);
		} finally {
			session.logout();
		}
	}

	@Override
	public Map<String, String> getProperties() throws InternalErrorException {

		return Collections.unmodifiableMap(map);
	}

	private Map<String,String> getProp(Node itemNode) throws InternalErrorException {
		Map<String,String> map = new HashMap<String,String>();
//		System.out.println("get map");
		Session session = null;
		//		Node itemNode = null;
		try {
			session = itemNode.getSession();
			//			itemNode = session.getNodeByIdentifier(identifier);

			Node propertiesNode = itemNode.getNode(PROPERTIES);

			for (PropertyIterator iterator = propertiesNode.getProperties();
					iterator.hasNext();) {
				Property property = iterator.nextProperty();
				if(!property.getName().startsWith("jcr:")) {
					String unescapeName = Text.unescape(property.getName());
					map.put(unescapeName,
							property.getValue().toString());
				}
			}

			return map;
		} catch (PathNotFoundException e) {
			if (itemNode!= null) {
				try {
					itemNode.addNode(PROPERTIES);
					session.save();
					return map; 
				} catch (RepositoryException e1) {
					logger.error("Error to add properties ",e1);
					throw new InternalErrorException(e1.getMessage());
				}
			} else {
				throw new InternalErrorException(e.getMessage());
			}
		} catch (RepositoryException e) {
			throw new InternalErrorException(e);
		} 

	}

	@Override
	public void addProperty(String name, String value) throws InternalErrorException {

		Validate.notNull(name,"Name property must be not null");
		Validate.notNull(value,"Value property must be not null");

		Session session = JCRRepository.getSession();
		try {
			Node itemNode = session.getNodeByIdentifier(identifier);
			String escapeName = Text.escapeIllegalJcrChars(name);
			itemNode.getNode(PROPERTIES).setProperty(escapeName, value);
			session.save();

			//update map
			map.put(escapeName, value);

		} catch (RepositoryException e) {
			throw new InternalErrorException(e);
		} finally {
			session.logout();
		}
	}

}

==> home-library-jcr-2.0.0-20150909.225934-84-sources.jar: org/gcube/common/homelibrary/jcr/workspace/JCRProperties.java <==
package org.gcube.common.homelibrary.jcr.workspace;

import java.util.Collections;
import java.util.Map;

import javax.jcr.RepositoryException;

import org.apache.commons.lang.Validate;
import org.apache.jackrabbit.util.Text;
import org.gcube.common.homelibary.model.items.ItemDelegate;
import org.gcube.common.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.common.homelibrary.home.workspace.Properties;
import org.gcube.common.homelibrary.jcr.workspace.servlet.wrapper.DelegateManager;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class JCRProperties implements Properties {

	private static Logger logger = LoggerFactory.getLogger(JCRProperties.class);


	private Map<String,String> map;
	private ItemDelegate itemDelegate;

	public JCRProperties(ItemDelegate itemDelegate) throws RepositoryException, InternalErrorException {

		this.itemDelegate = itemDelegate;
		this.map = itemDelegate.getMetadata();
	}


	@Override
	public String getId() throws InternalErrorException {

		return itemDelegate.getId();

	}

	@Override
	public String getPropertyValue(String propertyName) throws InternalErrorException {
		return map.get(propertyName);
	}

	@Override
	public Map<String, String> getProperties() throws InternalErrorException {
		return map;
	}


	@Override
	public void addProperty(String name, String value) throws InternalErrorException {

		Validate.notNull(name,"Name property must be not null");
		Validate.notNull(value,"Value property must be not null");

		try {
			String escapeName = Text.escapeIllegalJcrChars(name);
			map.put(escapeName, value);

		} catch (Exception e) {
			throw new InternalErrorException(e);
		}
	}


	@Override
	public void update() throws InternalErrorException {
		DelegateManager item = new DelegateManager(itemDelegate, "");
		try {
			item.save();
		} catch (Exception e) {
			logger.error("Error updating properties " , e);
		}

	}

}
